@@ -8,6 +8,20 @@
 #include <math.h>
 #include <Rinternals.h>
 #include <R_ext/Rdynload.h>
+//ckernel.f
+void wlinbin(double *x, double *w, int *n, double *a,
+	     double *b, int *m, int *trun, double *gcounts);
+void probin(double *x, double *y, int *n, double *a,
+	    double *b, int *m, double *gcounts);
+void yldist(double *gcounts, int *m, double *y);
+void ofcpdf(double *y, double *f,double *a, double *b,
+	    int *ny, double *x, int *nx, double *bw);
+void remp(int *n,double *y,double *f, double *a, double *b,
+	  int *m, double *Fx, double *x, double *u, int *ntotal);
+
+void mlensimp(double *w, double *f,double *a, double *b,
+	      int *n, double *theta);
+
 
 // fitdist.c
 void bootsd(int *size,double *x,double *y,double *sx,double *sy,
@@ -17,7 +31,6 @@ void fitdpro1(double *ll,double *ul, int *n,
 void fitdpro2(double *ll,double *ul, int *n1,
 	      double *x, int *n2,
 	      double *mu,double *s);
-
 // npr.c
 void awlprNorm(double *X0, int *n0,
 	     double *X, double *Y, double *W, int *size, 
@@ -45,7 +58,6 @@ void NWReg(double *Z, double *Y, int *size,
 
 void NormLap2(int *n, double *Rfx,double *ss, double *h1,
 	      double *grid,double *ub);
-
 // wnpr.c
 void wnpr(double *xgrid, int *ngrid, double *x, double *y, 
 	  double *w, int *size, double *bw, double *sx);
@@ -61,15 +73,6 @@ void wkde(double *y, double *w, int *n, double *x,double *fx,
 
 void wmise(double *x, double *w, int *n,
 	   double *h,double *g, int *m);
-//wkde.f
-void F77_SUB(wlinbin)(double *x, double *w, int *n, double *a,
-		      double *b, int *m, int *trun, double *gcounts);
-
-void F77_SUB(yldist)(double *gcounts, int *m, double *y);
-
-//binning.f
-void F77_SUB(probin)(double *x, double *y, int *n, double *a,
-		      double *b, int *m, double *gcounts);
 
 // cKDE.c
 void dKDE(double *x0, int *n0, double *xc, double *h, 
@@ -77,38 +80,12 @@ void dKDE(double *x0, int *n0, double *xc, double *h,
 void pKDE(double *x0, int *n0, double *xc, double *h, 
 	  double *f, int *n);
 
-//Fkernel.f
-void F77_SUB(linbin)(double *x, int *n, double *a, double *b,
-		     int *m, int *trun, double *gcounts);
-
-void F77_SUB(lbtwod)(double *x, int *n, double *a1,
-		     double *a2, double *b1, double *b2, int *m1,
-		     int *m2, double *gcounts);
-
-void F77_SUB(bintwod)(double *x, int *n, double *g1,
-		      double *g2, int *m1,
-		      int *m2, double *gcounts);
-
-void F77_SUB(iterfx)(double *fx, double *x0, int *n, double *x,
-		     double *f, int *m,
-		     double *w, double *h, int *iter);
-
-void F77_SUB(smoothkde)(double *fx, double *x0, int *n, 
-			double *x,  double *f, int *m,
-			double *w, double *h, int *iter);
 		    
 void rootGldFmklBisection(double *q, double *lambdas);
 void KSPvalue(double *x0);
 void KSP2x(double *x0, int *n);
 void pks2(double *x0, int *m, int *n);
 void hbmise(double *x, double *f, double *h, int *n, double *hopt);
-void F77_SUB(ofcpdf)(double *y, double *f,double *a, double *b,
-		     int *ny, double *x, int *nx, double *bw);
-void F77_SUB(remp)(int *n,double *y,double *f, double *a, double *b,
-		   int *m, double *Fx, double *x, double *u, 
-		   int *ntotal);
-void F77_SUB(mlensimp)(double *w, double *f,double *a, double *b,
-		     int *n, double *theta);
 
 
 // ckernel.c
@@ -131,7 +108,7 @@ void permtest3(double *xy, int *nx, int *ny, double *pv, int *iter);
 // em.c
 void em3(int *size, double *x, double *pars, double *tol);
 void bin2d(double *x, double *y, int *n, double *brk1, int *nb1,
-	   double brk2, int *nb2, double *cnt);
+	   double *brk2, int *nb2, double *cnt);
 
 
 //lognormal.c
@@ -250,9 +227,9 @@ static const R_FortranMethodDef FortEntries[] = {
   {"orexactu", (DL_FUNC) & orexactu, 3},
 
   {"hbmise", (DL_FUNC) & hbmise, 5},
-  {"ofcpdf", (DL_FUNC) &F77_SUB(ofcpdf), 8},
-  {"remp", (DL_FUNC) &F77_SUB(remp), 10},
-  {"mlensimp", (DL_FUNC) &F77_SUB(mlensimp), 6},
+  {"ofcpdf", (DL_FUNC) &ofcpdf, 8},
+  {"remp", (DL_FUNC) &remp, 10},
+  {"mlensimp", (DL_FUNC) &mlensimp, 6},
 
   {"pKDE", (DL_FUNC) & pKDE, 6},
   {"dKDE", (DL_FUNC) & dKDE, 6},
@@ -260,9 +237,9 @@ static const R_FortranMethodDef FortEntries[] = {
   {"wmise", (DL_FUNC) & wmise, 6},
   {"awkde", (DL_FUNC) & awkde, 8},
   {"wkde", (DL_FUNC) & wkde, 8},
-  {"wlinbin", (DL_FUNC) &F77_SUB(wlinbin),  8},
-  {"yldist", (DL_FUNC) &F77_SUB(yldist),  3},
-  {"probin", (DL_FUNC) &F77_SUB(probin), 7},
+  {"wlinbin", (DL_FUNC) &wlinbin, 8},
+  {"yldist", (DL_FUNC) &yldist,  3},
+  {"probin", (DL_FUNC) &probin, 7},
 
   {"wnpr", (DL_FUNC) & wnpr, 8},
   {"wdekde", (DL_FUNC) & wdekde, 7},
